onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
selectedCountryName = countries[0].name;
selectedCountryCode = countries[0].code;
selectedCountryFlagPath = countries[0].flagImagePath;
selectedCountryFormat = countries[0].phoneformat;
super.onInit();
}